@@ -133,7 +133,8 @@ extern int yydebug;
     VAR_MIN_RETRY_TIME = 343,
     VAR_MULTI_MASTER_CHECK = 344,
     VAR_MINIMAL_RESPONSES = 345,
-    VAR_REFUSE_ANY = 346
+    VAR_REFUSE_ANY = 346,
+    VAR_USE_SYSTEMD = 347
   };
 #endif
 /* Tokens.  */
@@ -226,6 +227,7 @@ extern int yydebug;
 #define VAR_MULTI_MASTER_CHECK 344
 #define VAR_MINIMAL_RESPONSES 345
 #define VAR_REFUSE_ANY 346
+#define VAR_USE_SYSTEMD 347
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -236,7 +238,7 @@ union YYSTYPE
 
 	char*	str;
 
-#line 240 "configparser.h" /* yacc.c:1909  */
+#line 242 "configparser.h" /* yacc.c:1909  */
 };
 
 typedef union YYSTYPE YYSTYPE;
