@@ -50,8 +50,7 @@
 struct nsd nsd;
 static char hostname[MAXHOSTNAMELEN];
 extern config_parser_state_type* cfg_parser;
-
-static void error(const char *format, ...) ATTR_FORMAT(printf, 1, 2);
+static void version(void) ATTR_NORETURN;
 
 /*
  * Print the help text.
@@ -115,56 +114,21 @@ version(void)
 	exit(0);
 }
 
-/*
- * Something went wrong, give error messages and exit.
- *
- */
-static void
-error(const char *format, ...)
-{
-	va_list args;
-	va_start(args, format);
-	log_vmsg(LOG_ERR, format, args);
-	va_end(args);
-	exit(1);
-}
-
-static void
-append_trailing_slash(const char** dirname, region_type* region)
-{
-	int l = strlen(*dirname);
-	if (l>0 && (*dirname)[l-1] != '/' && l < 0xffffff) {
-		char *dirname_slash = region_alloc(region, l+2);
-		memcpy(dirname_slash, *dirname, l+1);
-		strlcat(dirname_slash, "/", l+2);
-		/* old dirname is leaked, this is only used for chroot, once */
-		*dirname = dirname_slash;
-	}
-}
-
-static int
-file_inside_chroot(const char* fname, const char* chr)
-{
-	/* true if filename starts with chroot or is not absolute */
-	return ((fname && fname[0] && strncmp(fname, chr, strlen(chr)) == 0) ||
-		(fname && fname[0] != '/'));
-}
-
 void
 get_ip_port_frm_str(const char* arg, const char** hostname,
         const char** port)
 {
-        /* parse src[@port] option */
-        char* delim = NULL;
+	/* parse src[@port] option */
+	char* delim = NULL;
 	if (arg) {
 		delim = strchr(arg, '@');
 	}
 
-        if (delim) {
-                *delim = '\0';
-                *port = delim+1;
-        }
-        *hostname = arg;
+	if (delim) {
+		*delim = '\0';
+		*port = delim+1;
+	}
+	*hostname = arg;
 }
 
 /* append interface to interface array (names, udp, tcp) */
