@@ -2050,3 +2050,15 @@ unsigned getzonestatid(struct nsd_options* opt, struct zone_options* zopt)
 	return 0;
 #endif /* USE_ZONE_STATS */
 }
+
+/** check if config turns on IP-address interface with certificates or a
+ * named pipe without certificates. */
+int
+options_remote_is_address(struct nsd_options* cfg)
+{
+	if(!cfg->control_enable) return 0;
+	if(!cfg->control_interface) return 1;
+	if(!cfg->control_interface->address) return 1;
+	if(cfg->control_interface->address[0] == 0) return 1;
+	return (cfg->control_interface->address[0] != '/');
+}
